@@ -1,7 +1,7 @@
 /*
  * plugin-script.c - common functions used by script plugins
  *
- * Copyright (C) 2003-2021 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2023 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -158,16 +158,14 @@ plugin_script_create_dirs (struct t_weechat_plugin *weechat_plugin)
  *   - hooks config
  *   - creates directories in WeeChat home
  *   - hooks command, completion, hdata, infolist, signals
- *   - parses arguments
  *   - auto-loads scripts.
  */
 
 void
 plugin_script_init (struct t_weechat_plugin *weechat_plugin,
-                    int argc, char *argv[],
                     struct t_plugin_script_data *plugin_data)
 {
-    char string[512], *completion;
+    char string[512], *completion, *info_auto_load_scripts;
     char *action_signals[] = { "install", "remove", "autoload", NULL };
     int i, auto_load_scripts;
 
@@ -273,16 +271,13 @@ plugin_script_init (struct t_weechat_plugin *weechat_plugin,
                        &plugin_script_info_version_cb,
                        weechat_plugin, NULL);
 
-    /* parse arguments */
-    auto_load_scripts = 1;
-    for (i = 0; i < argc; i++)
-    {
-        if ((strcmp (argv[i], "-s") == 0)
-            || (strcmp (argv[i], "--no-script") == 0))
-        {
-            auto_load_scripts = 0;
-        }
-    }
+    /* check if auto-load of scripts is enabled */
+    info_auto_load_scripts = weechat_info_get ("auto_load_scripts", NULL);
+    auto_load_scripts = (info_auto_load_scripts
+                         && (strcmp (info_auto_load_scripts, "1") == 0)) ?
+        1 : 0;
+    if (info_auto_load_scripts)
+        free (info_auto_load_scripts);
 
     /* autoload scripts */
     if (auto_load_scripts)
@@ -481,21 +476,23 @@ plugin_script_auto_load (struct t_weechat_plugin *weechat_plugin,
 }
 
 /*
- * Searches for a script by registered name (example: "iset").
+ * Searches for a script by registered name.
  *
  * Returns pointer to script, NULL if not found.
  */
 
 struct t_plugin_script *
-plugin_script_search (struct t_weechat_plugin *weechat_plugin,
-                      struct t_plugin_script *scripts, const char *name)
+plugin_script_search (struct t_plugin_script *scripts, const char *name)
 {
     struct t_plugin_script *ptr_script;
 
+    if (!name)
+        return NULL;
+
     for (ptr_script = scripts; ptr_script;
          ptr_script = ptr_script->next_script)
     {
-        if (weechat_strcasecmp (ptr_script->name, name) == 0)
+        if (strcmp (ptr_script->name, name) == 0)
             return ptr_script;
     }
 
@@ -516,6 +513,9 @@ plugin_script_search_by_full_name (struct t_plugin_script *scripts,
     char *base_name;
     struct t_plugin_script *ptr_script;
 
+    if (!full_name)
+        return NULL;
+
     for (ptr_script = scripts; ptr_script;
          ptr_script = ptr_script->next_script)
     {
@@ -542,6 +542,9 @@ plugin_script_search_path (struct t_weechat_plugin *weechat_plugin,
     int length;
     struct stat st;
 
+    if (!filename)
+        return NULL;
+
     if (filename[0] == '~')
         return weechat_string_expand_home (filename);
 
@@ -635,7 +638,7 @@ plugin_script_find_pos (struct t_weechat_plugin *weechat_plugin,
 
     for (ptr_script = scripts; ptr_script; ptr_script = ptr_script->next_script)
     {
-        if (weechat_strcasecmp (script->name, ptr_script->name) < 0)
+        if (weechat_strcmp (script->name, ptr_script->name) < 0)
             return ptr_script;
     }
     return NULL;
@@ -817,8 +820,7 @@ plugin_script_set_buffer_callbacks (struct t_weechat_plugin *weechat_plugin,
                 script_name = weechat_buffer_get_string (ptr_buffer, "localvar_script_name");
                 if (script_name && script_name[0])
                 {
-                    ptr_script = plugin_script_search (weechat_plugin, scripts,
-                                                       script_name);
+                    ptr_script = plugin_script_search (scripts, script_name);
                     if (ptr_script && (ptr_script == script))
                     {
                         str_script_input_cb = weechat_buffer_get_string (
@@ -1287,8 +1289,11 @@ plugin_script_action_install (struct t_weechat_plugin *weechat_plugin,
                     {
                         snprintf (new_path, length, "%s/%s/%s",
                                   weechat_data_dir, weechat_plugin->name, base_name);
-                        if (rename (name, new_path) == 0)
+                        if (weechat_file_copy (name, new_path))
                         {
+                            /* remove old file */
+                            (void) remove (name);
+
                             /* make link in autoload dir */
                             if (autoload)
                             {
@@ -1751,7 +1756,7 @@ plugin_script_infolist_list_scripts (struct t_weechat_plugin *weechat_plugin,
                  ptr_script = ptr_script->next_script)
             {
                 if (!arguments || !arguments[0]
-                    || weechat_string_match (ptr_script->name, arguments, 0))
+                    || weechat_string_match (ptr_script->name, arguments, 1))
                 {
                     if (!plugin_script_add_to_infolist (weechat_plugin,
                                                         ptr_infolist, ptr_script))
